# Vegetronix VegeHub

This package is intended to simplify interactions with the [Vegetronix VegeHub](https://www.vegetronix.com/Products/VG-HUB-RELAY/). It allows remote setup of the API key and target server address, as well as simplifying retrieval of information about the Hub, including its MAC address.

This package was written for use with the VegeHub integration for [Home Assistant](https://www.home-assistant.io/), but may be used in other projects as well.

Development on this library was done using Python Poetry for dependency management and building/publishing. Find more info about how to use it [here](https://python-poetry.org/docs/basic-usage/).
